summaryrefslogtreecommitdiffstats
path: root/src/kile/kiledocumentinfo.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 19:59:21 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 19:59:21 +0000
commitb9c374725620ec064db7610132a8b8969fa405b9 (patch)
tree645c03144cac22f7b4fb5bd10985d389e8954290 /src/kile/kiledocumentinfo.h
parent71729070d61b36b96acd7fa9c34bba0cb8f58c3b (diff)
downloadkile-b9c374725620ec064db7610132a8b8969fa405b9.tar.gz
kile-b9c374725620ec064db7610132a8b8969fa405b9.zip
TQt4 port kile
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kile@1239285 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/kile/kiledocumentinfo.h')
-rw-r--r--src/kile/kiledocumentinfo.h87
1 files changed, 46 insertions, 41 deletions
diff --git a/src/kile/kiledocumentinfo.h b/src/kile/kiledocumentinfo.h
index fc534ef..9cc563f 100644
--- a/src/kile/kiledocumentinfo.h
+++ b/src/kile/kiledocumentinfo.h
@@ -52,7 +52,7 @@ namespace KileStruct
ToDo = 0x100000, FixMe = 0x200000, NewEnvironment = 0x400000
};
//Different levels (in the parent-child hierarchy) in the structure view
enum
{
Hidden = -4, NotSpecified = -3, Object = -2, File = -1
@@ -61,19 +61,19 @@ namespace KileStruct
/**
* A convenience class to store info about how LaTeX elements should appear in the
* structure view. A QMap<QString, KileStructData> should be created, so that the
* actual LaTeX elements can be mapped to this class.
**/
class KileStructData
{
public:
- KileStructData(int lvl = 0, int tp = KileStruct::None, QString px = QString::null, QString fldr = "root" ) : level(lvl), type(tp), pix(px), folder(fldr) {}
+ KileStructData(int lvl = 0, int tp = KileStruct::None, TQString px = TQString(), TQString fldr = "root" ) : level(lvl), type(tp), pix(px), folder(fldr) {}
/** At which level the element should be visible **/
int level;
/** The type of element (see @ref KileStruct) **/
int type;
/** The name of the icon that goes with this element. The icon is located using SmallIcon(pix). **/
- QString pix, folder;
+ TQString pix, folder;
};
/**
@@ -86,8 +86,8 @@ namespace KileDocument
struct BracketResult
{
- BracketResult() : option(QString::null), value(QString::null), line(0), col(0) {}
- QString option, value;
+ BracketResult() : option(TQString()), value(TQString()), line(0), col(0) {}
+ TQString option, value;
int line, col;
};
@@ -96,12 +96,13 @@ struct TodoResult
int type;
uint colTag;
uint colComment;
- QString comment;
+ TQString comment;
};
-class Info : public QObject
+class Info : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
static bool containsInvalidCharacters(const KURL&);
@@ -114,14 +115,14 @@ public:
Info();
~Info();
- const QStringList* labels() const{ return &m_labels; }
- const QStringList* bibItems() const { return &m_bibItems; }
- const QStringList* dependencies() const {return &m_deps; }
- const QStringList* bibliographies() const { return &m_bibliography; }
- const QStringList* packages() const { return &m_packages; }
- const QStringList* newCommands() const { return &m_newCommands; }
+ const TQStringList* labels() const{ return &m_labels; }
+ const TQStringList* bibItems() const { return &m_bibItems; }
+ const TQStringList* dependencies() const {return &m_deps; }
+ const TQStringList* bibliographies() const { return &m_bibliography; }
+ const TQStringList* packages() const { return &m_packages; }
+ const TQStringList* newCommands() const { return &m_newCommands; }
- QString lastModifiedFile(const QStringList *list = 0L);
+ TQString lastModifiedFile(const TQStringList *list = 0L);
bool openStructureLabels() { return m_openStructureLabels; }
bool openStructureReferences() { return m_openStructureReferences; }
@@ -131,7 +132,7 @@ public:
bool showStructureLabels() { return m_showStructureLabels; }
- const QString & preamble() const { return m_preamble; }
+ const TQString & preamble() const { return m_preamble; }
virtual bool isLaTeXRoot() { return m_bIsRoot; }
@@ -148,7 +149,7 @@ public:
/**
* Returns a file filter suitable for loading and saving files of this class' type.
**/
- virtual QString getFileFilter() const;
+ virtual TQString getFileFilter() const;
virtual bool isDocumentTypePromotionAllowed();
void setDocumentTypePromotionAllowed(bool b);
@@ -164,8 +165,8 @@ signals:
void urlChanged(KileDocument::Info* info, const KURL& url);
void isrootChanged(bool);
- void foundItem(const QString &title, uint line, uint column, int type, int level, uint startline, uint startcol,
- const QString & pix, const QString & folder);
+ void foundItem(const TQString &title, uint line, uint column, int type, int level, uint startline, uint startcol,
+ const TQString & pix, const TQString & folder);
void doneUpdating();
void depChanged();
void completed(KileDocument::Info* info);
@@ -174,7 +175,7 @@ protected slots:
void slotCompleted();
protected:
- void count(const QString line, long *stat);
+ void count(const TQString line, long *stat);
protected:
enum State
@@ -185,14 +186,14 @@ protected:
protected:
bool m_bIsRoot;
- QStringList m_labels;
- QStringList m_bibItems;
- QStringList m_deps, m_depsPrev;
- QStringList m_bibliography;
- QStringList m_packages;
- QStringList m_newCommands;
- QString m_preamble;
- QMap<QString,KileStructData> m_dictStructLevel;
+ TQStringList m_labels;
+ TQStringList m_bibItems;
+ TQStringList m_deps, m_depsPrev;
+ TQStringList m_bibliography;
+ TQStringList m_packages;
+ TQStringList m_newCommands;
+ TQString m_preamble;
+ TQMap<TQString,KileStructData> m_dictStructLevel;
KURL m_url;
KConfig *m_config;
bool m_showStructureLabels;
@@ -219,12 +220,13 @@ protected:
class TextInfo : public Info
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @param defaultHighlightMode the highlight mode that will be set automatically
* once a new document is installed
**/
- TextInfo(Kate::Document *doc, Extensions *extensions, const QString& defaultHighlightMode = QString::null);
+ TextInfo(Kate::Document *doc, Extensions *extensions, const TQString& defaultHighlightMode = TQString());
virtual ~TextInfo();
/**
@@ -252,9 +254,9 @@ public:
bool isTextDocument();
- void setHighlightMode(const QString & highlight = QString::null);
+ void setHighlightMode(const TQString & highlight = TQString());
- void setDefaultHightlightMode(const QString& string);
+ void setDefaultHightlightMode(const TQString& string);
/**
* "Overridden" method that installs custom event filters by using the "installEventFilters"
@@ -262,7 +264,7 @@ public:
* @warning Only this method should be used to create new views for text documents !
* @return NULL if no document is set (m_doc == NULL)
**/
- KTextEditor::View* createView(QWidget *parent, const char *name=0);
+ KTextEditor::View* createView(TQWidget *tqparent, const char *name=0);
protected slots:
void slotFileNameChanged();
@@ -270,11 +272,11 @@ protected slots:
protected:
Kate::Document *m_doc;
long *m_arStatistics;
- QString m_defaultHighlightMode;
+ TQString m_defaultHighlightMode;
- QString matchBracket(QChar c, uint &, uint &);
- QString getTextline(uint line, TodoResult &todo);
- void searchTodoComment(const QString &s, uint startpos, TodoResult &todo);
+ TQString matchBracket(TQChar c, uint &, uint &);
+ TQString getTextline(uint line, TodoResult &todo);
+ void searchTodoComment(const TQString &s, uint startpos, TodoResult &todo);
/**
* Installs an event filter on a view. Subclasses can override this method to
@@ -312,26 +314,27 @@ protected:
class LaTeXInfo : public TextInfo
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @param eventFilter the event filter that will be installed on managed documents
**/
- LaTeXInfo(Kate::Document *doc, Extensions *extensions, LatexCommands *commands, const QObject* eventFilter);
+ LaTeXInfo(Kate::Document *doc, Extensions *extensions, LatexCommands *commands, const TQObject* eventFilter);
virtual ~LaTeXInfo();
const long* getStatistics();
virtual Type getType();
- virtual QString getFileFilter() const;
+ virtual TQString getFileFilter() const;
public slots:
virtual void updateStruct();
protected:
LatexCommands *m_commands;
- const QObject *m_eventFilter;
+ const TQObject *m_eventFilter;
virtual void updateStructLevelInfo();
virtual void checkChangedDeps();
@@ -354,6 +357,7 @@ private:
class BibInfo : public TextInfo
{
Q_OBJECT
+ TQ_OBJECT
public:
BibInfo (Kate::Document *doc, Extensions *extensions, LatexCommands* commands);
@@ -363,7 +367,7 @@ public:
virtual Type getType();
- virtual QString getFileFilter() const;
+ virtual TQString getFileFilter() const;
public slots:
virtual void updateStruct();
@@ -372,6 +376,7 @@ public slots:
class ScriptInfo : public TextInfo
{
Q_OBJECT
+ TQ_OBJECT
public:
ScriptInfo(Kate::Document *doc, Extensions *extensions);
@@ -381,7 +386,7 @@ public:
virtual Type getType();
- virtual QString getFileFilter() const;
+ virtual TQString getFileFilter() const;
};
}
@@ -52,7 +52,7 @@ namespace KileStruct
ToDo = 0x100000, FixMe = 0x200000, NewEnvironment = 0x400000
};
- //Different levels (in the parent-child hierarchy) in the structure view
+ //Different levels (in the tqparent-child hierarchy) in the structure view
enum
{
@@ -61,19 +61,19 @@ namespace KileStruct
/**
* A convenience class to store info about how LaTeX elements should appear in the
- * structure view. A QMap<QString, KileStructData> should be created, so that the
+ * structure view. A TQMap<TQString, KileStructData> should be created, so that the
* actual LaTeX elements can be mapped to this class.
**/